LevelFilter

Enum LevelFilter 

#[repr(align(4))]
pub enum LevelFilter { Off, Equal(Level), NotEqual(Level), MoreSevere(Level), MoreSevereEqual(Level), MoreVerbose(Level), MoreVerboseEqual(Level), All, }
Represents log level logical filter conditions.

Use LevelFilter::test method to check if a Level satisfies the filter condition.

Variants



Off

Disables all levels.



Equal(Level)

Enables if the target level is equal to the filter level.



NotEqual(Level)

Enables if the target level is not equal to the filter level.



MoreSevere(Level)

Enables if the target level is more severe than the filter level.



MoreSevereEqual(Level)

Enables if the target level is more severe than or equal to the filter level.



MoreVerbose(Level)

Enables if the target level is more verbose than the filter level.



MoreVerboseEqual(Level)

Enables if the target level is more verbose than or equal to the filter level.



All

Enables all levels.

Implementations

Source

impl LevelFilter

pub fn compare(&self, level: Level) -> bool

👎Deprecated since 0.4.0:

it may be removed in the future, use method test() instead

Checks the given level if satisfies the filter condition.

pub fn test(&self, level: Level) -> bool

Checks the given level if satisfies the filter condition.

Examples
use spdlog::prelude::*;

let level_filter = LevelFilter::MoreSevere(Level::Info);

assert_eq!(level_filter.test(Level::Trace), false);
assert_eq!(level_filter.test(Level::Info), false);
assert_eq!(level_filter.test(Level::Warn), true);
assert_eq!(level_filter.test(Level::Error), true);